@@ -7,11 +7,11 @@
 #define QT_FEATURE_private_tests -1
 #define QT_FEATURE_dbus 1
 #define QT_FEATURE_dbus_linked 1
+#define QT_FEATURE_gc_binaries -1
 #define QT_FEATURE_gui 1
 #define QT_FEATURE_libudev 1
 #define QT_FEATURE_network 1
 #define QT_FEATURE_posix_fallocate 1
-#define QT_FEATURE_qml_debug 1
 #define QT_FEATURE_reduce_exports 1
 #define QT_FEATURE_reduce_relocations -1
 #define QT_FEATURE_release_tools 1
