@@ -51,7 +51,7 @@
 // We mean it.
 //
 
-#include <QtCore/qglobal.h>
+#include <QtGui/private/qtguiglobal_p.h>
 
 #include <QMap>
 #include <QVector>
@@ -71,12 +71,12 @@ struct Q_GUI_EXPORT QImageData {        // internal image data
     int width;
     int height;
     int depth;
-    int nbytes;               // number of bytes data
+    qsizetype nbytes;               // number of bytes data
     qreal devicePixelRatio;
     QVector<QRgb> colortable;
     uchar *data;
     QImage::Format format;
-    int bytes_per_line;
+    qsizetype bytes_per_line;
     int ser_no;               // serial number
     int detach_no;
 
@@ -113,6 +113,7 @@ extern Image_Converter qimage_converter_map[QImage::NImageFormats][QImage::NImag
 extern InPlace_Image_Converter qimage_inplace_converter_map[QImage::NImageFormats][QImage::NImageFormats];
 
 void convert_generic(QImageData *dest, const QImageData *src, Qt::ImageConversionFlags);
+void convert_generic_to_rgb64(QImageData *dest, const QImageData *src, Qt::ImageConversionFlags);
 bool convert_generic_inplace(QImageData *data, QImage::Format dst_format, Qt::ImageConversionFlags);
 
 void dither_to_Mono(QImageData *dst, const QImageData *src, Qt::ImageConversionFlags flags, bool fromalpha);
@@ -164,6 +165,11 @@ inline int qt_depthForFormat(QImage::Format format)
     case QImage::Format_RGB888:
         depth = 24;
         break;
+    case QImage::Format_RGBX64:
+    case QImage::Format_RGBA64:
+    case QImage::Format_RGBA64_Premultiplied:
+        depth = 64;
+        break;
     }
     return depth;
 }
@@ -172,6 +178,34 @@ inline int qt_depthForFormat(QImage::Format format)
 #pragma optimize("", on)
 #endif
 
+inline QImage::Format qt_opaqueVersion(QImage::Format format)
+{
+    switch (format) {
+    case QImage::Format_ARGB8565_Premultiplied:
+        return  QImage::Format_RGB16;
+    case QImage::Format_ARGB8555_Premultiplied:
+        return QImage::Format_RGB555;
+    case QImage::Format_ARGB6666_Premultiplied:
+        return  QImage::Format_RGB666;
+    case QImage::Format_ARGB4444_Premultiplied:
+        return QImage::Format_RGB444;
+    case QImage::Format_RGBA8888:
+    case QImage::Format_RGBA8888_Premultiplied:
+        return QImage::Format_RGBX8888;
+    case QImage::Format_A2BGR30_Premultiplied:
+        return QImage::Format_BGR30;
+    case QImage::Format_A2RGB30_Premultiplied:
+        return QImage::Format_RGB30;
+    case QImage::Format_RGBA64:
+    case QImage::Format_RGBA64_Premultiplied:
+        return QImage::Format_RGBX64;
+    case QImage::Format_ARGB32_Premultiplied:
+    case QImage::Format_ARGB32:
+    default:
+        return QImage::Format_RGB32;
+    }
+}
+
 inline QImage::Format qt_alphaVersion(QImage::Format format)
 {
     switch (format) {
@@ -189,6 +223,8 @@ inline QImage::Format qt_alphaVersion(QImage::Format format)
         return QImage::Format_A2BGR30_Premultiplied;
     case QImage::Format_RGB30:
         return QImage::Format_A2RGB30_Premultiplied;
+    case QImage::Format_RGBX64:
+        return QImage::Format_RGBA64_Premultiplied;
     default:
         break;
     }
@@ -201,6 +237,11 @@ inline QImage::Format qt_maybeAlphaVersionWithSameDepth(QImage::Format format)
     return qt_depthForFormat(format) == qt_depthForFormat(toFormat) ? toFormat : format;
 }
 
+inline QImage::Format qt_opaqueVersionForPainting(QImage::Format format)
+{
+    return qt_opaqueVersion(format);
+}
+
 inline QImage::Format qt_alphaVersionForPainting(QImage::Format format)
 {
     QImage::Format toFormat = qt_alphaVersion(format);
@@ -212,6 +253,9 @@ inline QImage::Format qt_alphaVersionForPainting(QImage::Format format)
     return toFormat;
 }
 
+Q_GUI_EXPORT QMap<QString, QString> qt_getImageText(const QImage &image, const QString &description);
+Q_GUI_EXPORT QMap<QString, QString> qt_getImageTextFromDescription(const QString &description);
+
 QT_END_NAMESPACE
 
 #endif // QIMAGE_P_H
